@@ -22,12 +22,12 @@ from framework.exit_code import ExitCode
 from framework.db.mysql_db import MysqlDB
 from framework.db.redis_db import RedisDB
 from framework.utils.log_util import logger
-from framework.render_data import RenderData
+# from framework.render_data import RenderData
 from framework.utils.yaml_util import YamlUtil
+from framework.settings import DATA_DIR, CASES_DIR
 from framework.allure_report import generate_report
 from framework.global_attribute import CONTEXT, CONFIG, _FRAMEWORK_CONTEXT
 from framework.utils.common import snake_to_pascal, get_apps, convert_numbers_to_decimal
-from config.settings import DATA_DIR, CASES_DIR
 
 all_app = get_apps()
 module = importlib.import_module("test_case.conftest")
@@ -139,6 +139,12 @@ def pytest_generate_tests(metafunc):
         if not case_common.get("url"):
             logger.warning(f"{func_file_path} request中缺少必填字段: url", case_data)
             # pytest.exit(ExitCode.YAML_MISSING_FIELDS)
+        else:
+            url = case_common.get("url")
+            if url.strip().startswith("${"):
+                case_data["request"]["url"] = url
+            else:
+                case_data["request"]["url"] = urljoin(domain, url)
     else:
         if url.strip().startswith("${"):
             case_data["request"]["url"] = url
@@ -150,6 +156,8 @@ def pytest_generate_tests(metafunc):
         if not case_common.get("method"):
             logger.warning(f"{func_file_path} request中缺少必填字段: method", case_data)
             # pytest.exit(ExitCode.YAML_MISSING_FIELDS)
+        else:
+            case_data["request"]["method"] = case_common.get("method")
 
     for key in ["title", "level"]:
         if key not in case_data:
@@ -179,8 +187,9 @@ def pytest_generate_tests(metafunc):
                 # 剔除标记disable的字段
                 deep_copied_case_data = disable_field(scenario.get("data"), deep_copied_case_data)
                 deep_copied_case_data["_scenario"] = item.get("scenario")
+                deep_copied_case_data["_ignore_failed"] = case_common.get("ignore_failed", False)
                 case_data_list.append(deep_copied_case_data)
-                ids.append(case_data.get("title") + f"#{index + 1}")
+                ids.append(f'{case_data.get("title")} - {scenario.get("describe", "")}#{index + 1}')
             except KeyError as e:
                 logger.error(f"scenario参数化格式不正确:{e}")
                 traceback.print_exc()
@@ -189,6 +198,7 @@ def pytest_generate_tests(metafunc):
     else:
         if not case_common.get("ignore"):
             case_data["_scenario"] = {"data": {}}
+            case_data["_ignore_failed"] = case_common.get("ignore_failed", False)
             case_data_list = [case_data]
         # 进行参数化生成用例
         metafunc.parametrize("data", case_data_list, ids=[f'{case_data.get("title")}#1'], scope="function")
@@ -408,9 +418,11 @@ def pytest_runtest_call(item):
     :param item:
     :return:
     """
+    origin_data = item.funcargs.get("data")
     func_name = item.originalname
+    ignore_failed = origin_data.get("_ignore_failed")
     ignore_error_and_continue = item.config.getini("ignore_error_and_continue")
-    if ignore_error_and_continue == "false":
+    if not (ignore_failed is True or ignore_error_and_continue == "true"):
         # setup方法执行失败，则主动标记用例执行失败，不会执行用例
         if item.funcargs.get("setup_success") is False:
             pytest.skip("test_before_scenario execute error")
@@ -590,6 +602,15 @@ def login():
         mysqls = CONFIG.get(app=app, key="mysql")
         mysqls_obj = {item: MysqlDB(**mysqls.get(item)) for item in mysqls.keys()}
         _FRAMEWORK_CONTEXT.set(app=app, key="mysql", value=mysqls_obj)
+        redis = CONFIG.get(app=app, key="redis")
+        redis_obj = {
+            db: [
+                RedisDB(**{**db_info, "db": i})
+                for i in range(16)
+            ]
+            for db, db_info in redis.items()
+        }
+        _FRAMEWORK_CONTEXT.set(app=app, key="redis", value=redis_obj)
 
     try:
         logger.info("登录账号".center(80, "*"))
