@@ -11,8 +11,27 @@ from urllib.parse import unquote, quote, quote_plus, unquote_plus
 import pyotp
 import cn2an as c2a
 from faker import Faker
+from framework.settings import CONFIG_DIR
 
-from config.settings import CONFIG_DIR
+try:
+    from utils.common import *
+except ImportError:
+    pass
+
+
+class SingletonFaker(object):
+    instance = None
+    init_flag = False
+
+    def __init__(self, locale):
+        if self.init_flag:
+            return
+        self.faker = Faker(locale)
+
+    def __new__(cls, *args, **kwargs):
+        if cls.instance is None:
+            cls.instance = super().__new__(cls)
+        return cls.instance
 
 
 def generate_2fa_code(secret_key):
@@ -243,19 +262,9 @@ def convert_numbers_to_decimal(obj: Any) -> Any:
         return obj
 
 
-class SingletonFaker(object):
-    instance = None
-    init_flag = False
-
-    def __init__(self, locale):
-        if self.init_flag:
-            return
-        self.faker = Faker(locale)
-
-    def __new__(cls, *args, **kwargs):
-        if cls.instance is None:
-            cls.instance = super().__new__(cls)
-        return cls.instance
+def remove_spaces(s: str) -> str:
+    """去掉字符串中的所有空格"""
+    return s.replace(" ", "")
 
 
 if __name__ == '__main__':
